paidiverpy.utils.exceptions
===========================

.. py:module:: paidiverpy.utils.exceptions

.. autoapi-nested-parse::

   Exception classes.

   ..
       !! processed by numpydoc !!


Functions
---------

.. autoapisummary::

   paidiverpy.utils.exceptions.raise_value_error


Module Contents
---------------

.. py:function:: raise_value_error(message: str) -> None

   
   Raise a ValueError with the given message.

   :param message: The message to raise the ValueError with.
   :type message: str















   ..
       !! processed by numpydoc !!

